from _typeshed import Incomplete

PERF_DATA_VERSION: int
PERF_DATA_REVISION: int
PERF_NO_INSTANCES: int
PERF_SIZE_DWORD: int
PERF_SIZE_LARGE: int
PERF_SIZE_ZERO: int
PERF_SIZE_VARIABLE_LEN: int
PERF_TYPE_NUMBER: int
PERF_TYPE_COUNTER: int
PERF_TYPE_TEXT: int
PERF_TYPE_ZERO: int
PERF_NUMBER_HEX: int
PERF_NUMBER_DECIMAL: int
PERF_NUMBER_DEC_1000: int
PERF_COUNTER_VALUE: int
PERF_COUNTER_RATE: int
PERF_COUNTER_FRACTION: int
PERF_COUNTER_BASE: int
PERF_COUNTER_ELAPSED: int
PERF_COUNTER_QUEUELEN: int
PERF_COUNTER_HISTOGRAM: int
PERF_TEXT_UNICODE: int
PERF_TEXT_ASCII: int
PERF_TIMER_TICK: int
PERF_TIMER_100NS: int
PERF_OBJECT_TIMER: int
PERF_DELTA_COUNTER: int
PERF_DELTA_BASE: int
PERF_INVERSE_COUNTER: int
PERF_MULTI_COUNTER: int
PERF_DISPLAY_NO_SUFFIX: int
PERF_DISPLAY_PER_SEC: int
PERF_DISPLAY_PERCENT: int
PERF_DISPLAY_SECONDS: int
PERF_DISPLAY_NOSHOW: int
PERF_COUNTER_COUNTER: Incomplete
PERF_COUNTER_TIMER: Incomplete
PERF_COUNTER_QUEUELEN_TYPE: Incomplete
PERF_COUNTER_LARGE_QUEUELEN_TYPE: Incomplete
PERF_COUNTER_BULK_COUNT: Incomplete
PERF_COUNTER_TEXT: Incomplete
PERF_COUNTER_RAWCOUNT: Incomplete
PERF_COUNTER_LARGE_RAWCOUNT: Incomplete
PERF_COUNTER_RAWCOUNT_HEX: Incomplete
PERF_COUNTER_LARGE_RAWCOUNT_HEX: Incomplete
PERF_SAMPLE_FRACTION: Incomplete
PERF_SAMPLE_COUNTER: Incomplete
PERF_COUNTER_NODATA: Incomplete
PERF_COUNTER_TIMER_INV: Incomplete
PERF_SAMPLE_BASE: Incomplete
PERF_AVERAGE_TIMER: Incomplete
PERF_AVERAGE_BASE: Incomplete
PERF_AVERAGE_BULK: Incomplete
PERF_100NSEC_TIMER: Incomplete
PERF_100NSEC_TIMER_INV: Incomplete
PERF_COUNTER_MULTI_TIMER: Incomplete
PERF_COUNTER_MULTI_TIMER_INV: Incomplete
PERF_COUNTER_MULTI_BASE: Incomplete
PERF_100NSEC_MULTI_TIMER: Incomplete
PERF_100NSEC_MULTI_TIMER_INV: Incomplete
PERF_RAW_FRACTION: Incomplete
PERF_RAW_BASE: Incomplete
PERF_ELAPSED_TIME: Incomplete
PERF_COUNTER_HISTOGRAM_TYPE: int
PERF_COUNTER_DELTA: Incomplete
PERF_COUNTER_LARGE_DELTA: Incomplete
PERF_DETAIL_NOVICE: int
PERF_DETAIL_ADVANCED: int
PERF_DETAIL_EXPERT: int
PERF_DETAIL_WIZARD: int
PERF_NO_UNIQUE_ID: int
