import _win32typing

OPENSTORE_HOME_LOGON: int
OPENSTORE_OVERRIDE_HOME_MDB: int
OPENSTORE_PUBLIC: int
OPENSTORE_TAKE_OWNERSHIP: int
OPENSTORE_USE_ADMIN_PRIVILEGE: int
IID_IExchangeManageStore: _win32typing.PyIID
IID_IExchangeManageStoreEx: _win32typing.PyIID
