from _typeshed import Incomplete

class ISAPIError(Exception):
    errno: Incomplete
    strerror: Incomplete
    funcname: Incomplete
    def __init__(self, errno, strerror: Incomplete | None = None, funcname: Incomplete | None = None) -> None: ...

class FilterError(ISAPIError): ...
class ExtensionError(ISAPIError): ...
class InternalReloadException(Exception): ...
